@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 import uwsgi
 import gevent.select
 from ws4redis.exceptions import WebSocketError
@@ -13,7 +13,7 @@ class uWSGIWebsocket(object):
         """Return the file descriptor for the given websocket"""
         try:
             return uwsgi.connection_fd()
-        except IOError, e:
+        except IOError as e:
             self.close()
             raise WebSocketError(e)
 
@@ -26,17 +26,20 @@ class uWSGIWebsocket(object):
             raise WebSocketError("Connection is already closed")
         try:
             return uwsgi.websocket_recv_nb()
-        except IOError, e:
+        except IOError as e:
             self.close()
             raise WebSocketError(e)
 
     def flush(self):
-        self.receive()
+        try:
+            uwsgi.websocket_recv_nb()
+        except IOError:
+            self.close()
 
     def send(self, message, binary=None):
         try:
             uwsgi.websocket_send(message)
-        except IOError, e:
+        except IOError as e:
             self.close()
             raise WebSocketError(e)
 
